import{d as a,o,K as s,b as d,u as r,br as _,Q as c}from"./index.a59ca186.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="4b0fb1b2-82ff-424a-bb83-775c313ae931",e._sentryDebugIdIdentifier="sentry-dbid-4b0fb1b2-82ff-424a-bb83-775c313ae931")}catch{}})();const i={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[d(r(_))]))}});const p=c(f,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.2a8a012f.js.map
