import{P as f}from"./PlayerNavbar.6703ece4.js";import{d as g,e3 as h,e4 as c,f as b,g as y,r as k,K as v,u as a,c as w,F as L,a as C,b as I,o as i,Q as N}from"./index.a59ca186.js";import{u as V}from"./workspaceStore.933ebf86.js";import"./userStore.ae2e441a.js";import"./metadata.fd28ad62.js";import"./PhWebhooksLogo.vue.8b359f70.js";import"./LoadingOutlined.2bc654ae.js";import"./PhSignOut.vue.aecb5a1e.js";import"./index.0ac48987.js";import"./Avatar.459ee620.js";import"./runnerData.a36e7caa.js";import"./url.058cc2c6.js";import"./colorHelpers.c372ec9c.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="2d2bb3f3-80d1-4082-9de6-43480b2e92cc",o._sentryDebugIdIdentifier="sentry-dbid-2d2bb3f3-80d1-4082-9de6-43480b2e92cc")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=c().path,n=b(null),u=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},_=y(()=>!!c().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return i(),v("div",x,[a(t).state.workspace?(i(),w(f,{key:0,"current-path":a(d),"hide-login":_.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:u,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.0a4389ea.js.map
