import{d as i,e3 as m,e4 as p,o as l,c as f,w as d,K as _,ea as g,b as y,a as v,eb as w,u as n,aL as k}from"./index.a59ca186.js";import{A as I,T}from"./TabPane.a71b57bf.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="bd5f6511-03bd-4aad-beb9-23ac5684968e",e._sentryDebugIdIdentifier="sentry-dbid-bd5f6511-03bd-4aad-beb9-23ac5684968e")}catch{}})();const S=i({__name:"TablesTabs",setup(e){const a=m(),t=p(),u=String(t.name),c=t.params.projectId,r=[{label:"Tables list",value:"tables"},{label:"Diagram view",value:"tables-diagram"},{label:"Run SQL",value:"sql"}],b=o=>{a.push({name:String(o),params:{projectId:c}})};return(o,D)=>(l(),f(n(T),{"active-key":n(u),options:r,"onUpdate:activeKey":b},{default:d(()=>[(l(),_(k,null,g(r,s=>y(n(I),{key:s.value,name:s.value},{tab:d(()=>[v("span",null,w(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{S as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang.01edb56e.js.map
