import{L as n}from"./Logo.00f1cdb8.js";import{d as a,o as r,c as d,u as i}from"./index.a59ca186.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="14ca829b-2991-4111-806c-de4c8db56416",e._sentryDebugIdIdentifier="sentry-dbid-14ca829b-2991-4111-806c-de4c8db56416")}catch{}})();const c="/assets/logo.0faadfa2.svg",u=a({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(s,t)=>{var o;return r(),d(n,{"image-url":i(c),"brand-name":"Abstra","hide-text":s.hideText,size:(o=s.size)!=null?o:"small"},null,8,["image-url","hide-text","size"])}}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.44247f27.js.map
