import{O as r}from"./userStore.ae2e441a.js";import{d as l,J as u,K as i,b as t,w as n,u as o,o as c,az as d,d6 as f,d5 as b}from"./index.a59ca186.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="9cd9583b-ff63-4d0c-aa86-80a96b2da62a",e._sentryDebugIdIdentifier="sentry-dbid-9cd9583b-ff63-4d0c-aa86-80a96b2da62a")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new r().logoutCallback()}),(a,s)=>(c(),i("div",null,[t(o(f),null,{default:n(()=>[d("You're authenticated")]),_:1}),t(o(b),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.15c21d45.js.map
