import"./index.a59ca186.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="6f2f2220-3702-4523-949a-bd3d706db55a",x._sentryDebugIdIdentifier="sentry-dbid-6f2f2220-3702-4523-949a-bd3d706db55a")}catch{}})();const t=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{t as u};
//# sourceMappingURL=uuid.90494b4a.js.map
