import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.fb6d29e2.js";import{R as f}from"./tasksController.0c3cb2d7.js";import{d as _,e4 as b,g,K as y,b as w,w as k,u as n,c as I,F as T,aL as v,o as d,az as B,d6 as j}from"./index.a59ca186.js";import"./gateway.e14a87cc.js";import{a as x,B as C}from"./build.fb9f0ee4.js";import{P as D}from"./project.a76802ac.js";import"./columns.5de4a954.js";import{a as R}from"./asyncComputed.883f99d7.js";import"./metadata.fd28ad62.js";import"./PhWebhooksLogo.vue.8b359f70.js";import"./ant-design.c46171b2.js";import"./string.33cd155c.js";import"./index.1cf59b43.js";import"./dayjs.2d513ded.js";import"./linters.7f594867.js";import"./scripts.c09fb5d3.js";import"./record.6981eb70.js";import"./polling.773eec85.js";import"./popupNotifcation.55c3d770.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="5d4ccd7f-1f9c-4b6a-8da0-f1a3ed023a4e",e._sentryDebugIdIdentifier="sentry-dbid-5d4ccd7f-1f9c-4b6a-8da0-f1a3ed023a4e")}catch{}})();const U=_({__name:"Tasks",setup(e){const a=b().params.projectId,l=new f(a),{result:o}=R(async()=>{const r=(await x.list(a)).find(u=>u.latest);if(!r)return null;const[c,p]=await Promise.all([C.get(r.id),D.get(a)]);return{buildSpec:c,project:p}}),i=g(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(d(),y(v,null,[w(n(j),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(d(),I(m,{key:0,class:"tasks",api:n(l),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.6f997bd7.js.map
