import{C as t,E as i,K as c,a as d,M as f,c as b,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.0489d4cb.js";import"./index.a59ca186.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="294ec59b-13fb-4626-b1ce-7ff0938c75c7",e._sentryDebugIdIdentifier="sentry-dbid-294ec59b-13fb-4626-b1ce-7ff0938c75c7")}catch{}})();export{t as CancellationTokenSource,i as Emitter,c as KeyCode,d as KeyMod,f as MarkerSeverity,b as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.fc2bd12d.js.map
