import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.d6ed84fb.js";import{d as m,e3 as f,e4 as b,K as g,b as y,u as a,o as w,Q as k}from"./index.a59ca186.js";import{u as h}from"./workspaceStore.933ebf86.js";import"./userStore.ae2e441a.js";import"./CircularLoading.13d32503.js";import"./Logo.00f1cdb8.js";import"./string.33cd155c.js";import"./index.378659cf.js";import"./runnerData.a36e7caa.js";import"./url.058cc2c6.js";import"./colorHelpers.c372ec9c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f0813e9e-452c-4591-8e16-2e4365db5cf6",e._sentryDebugIdIdentifier="sentry-dbid-f0813e9e-452c-4591-8e16-2e4365db5cf6")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),t=b(),r=h(),_=async()=>{const{redirect:s,...n}=t.query;if(s){await o.push({path:s,query:n,params:t.params});return}o.push({name:"playerHome",query:n})};return(s,n)=>{var c,p,u,d,i;return w(),g("div",v,[y(l,{"logo-url":(p=(c=a(r).state.workspace)==null?void 0:c.logoUrl)!=null?p:void 0,"brand-name":(u=a(r).state.workspace)==null?void 0:u.brandName,locale:(i=(d=a(r).state.workspace)==null?void 0:d.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const K=k(I,[["__scopeId","data-v-cb33c596"]]);export{K as default};
//# sourceMappingURL=Login.2538accc.js.map
