import{m as n,n as r,T as a,p as o,P as d,C as p,M as c,s as m,q as s,t as u,v as f,x as b,y as g}from"./index.a59ca186.js";import{s as y}from"./userStore.ae2e441a.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.0a6c4a4f.js";import{a as i}from"./workspaceStore.933ebf86.js";import"./PlayerConfigProvider.b215a36d.js";import"./colorHelpers.c372ec9c.js";import"./index.27fd63a3.js";import"./runnerData.a36e7caa.js";import"./url.058cc2c6.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="1467ddb8-5a2b-4d38-8148-7eb4d0b4c7cd",t._sentryDebugIdIdentifier="sentry-dbid-1467ddb8-5a2b-4d38-8148-7eb4d0b4c7cd")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=n(),e=r({render:()=>u(l)});a.init(),o(e,i),w.init(),e.use(i),e.use(t),e.use(d),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",c),e.component("Message",m),s(e,f),s(e,b),s(e,g)})();
//# sourceMappingURL=player.104fc875.js.map
