import{O as s,R as a}from"./OmniChat.23804570.js";import{d as c,e4 as d,o as i,c as f,u as n}from"./index.a59ca186.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b8327951-d54e-4c21-ad6f-74cf94c4dd82",e._sentryDebugIdIdentifier="sentry-dbid-b8327951-d54e-4c21-ad6f-74cf94c4dd82")}catch{}})();const _=c({__name:"ConsoleOmniChat",setup(e){const t=d().params.projectId,r=new a(t);return(p,u)=>(i(),f(s,{"ai-chat-repository":n(r),environment:{origin:"console",projectId:n(t)}},null,8,["ai-chat-repository","environment"]))}});export{_};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.15d0b3f5.js.map
