import{P as d}from"./record.6981eb70.js";import{e as r,f as u}from"./index.a59ca186.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="5edba26a-3dfd-4e21-aba6-d2c05d0aa4aa",e._sentryDebugIdIdentifier="sentry-dbid-5edba26a-3dfd-4e21-aba6-d2c05d0aa4aa")}catch{}})();const i=new d,b=r("omniChat",()=>{const e=u(!1),a=u(!1),t=()=>{a.value=!0},n=()=>{a.value=!1},s=()=>{e.value=!0,t()},o=()=>{e.value=!1,n()};return{isOpen:e,isInputFocused:a,focusInput:t,blurInput:n,open:s,close:o,toggle:()=>{e.value?o():s()}}});export{i as o,b as u};
//# sourceMappingURL=omniChatStore.dbe1dbde.js.map
