import{C as p}from"./controller.1c462665.js";import{d as i,e4 as n,c as s,u as m,o as c}from"./index.a59ca186.js";import{_ as f}from"./View.vue_vue_type_script_setup_true_lang.855386dc.js";import"./gateway.e14a87cc.js";import"./popupNotifcation.55c3d770.js";import"./fetch.29ff9ac6.js";import"./record.6981eb70.js";import"./PhPencil.vue.f45c727f.js";import"./SaveButton.27a105d7.js";import"./UnsavedChangesHandler.70782e80.js";import"./ExclamationCircleOutlined.a7d6c013.js";import"./CrudView.cdf2b3ec.js";import"./router.179446c8.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.e785979a.js";import"./url.058cc2c6.js";import"./PhDotsThreeVertical.vue.b78f3770.js";import"./Badge.d0d1aeb3.js";import"./index.c0748d2f.js";import"./index.1cf59b43.js";import"./asyncComputed.883f99d7.js";import"./polling.773eec85.js";import"./omniChatStore.dbe1dbde.js";import"./index.378659cf.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="f7c60513-0c3f-40f2-865e-7dbbe4fe3cce",o._sentryDebugIdIdentifier="sentry-dbid-f7c60513-0c3f-40f2-865e-7dbbe4fe3cce")}catch{}})();const F=i({__name:"EnvVars",setup(o){const r=n().params.projectId,t=new p(r);return(a,d)=>(c(),s(f,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{F as default};
//# sourceMappingURL=EnvVars.38d1bd9a.js.map
