import{B as e}from"./BaseLayout.a16dd66f.js";import{d as a,e4 as n,r as s,c as f,w as r,o as c,b as i,u}from"./index.a59ca186.js";import{N as d,_}from"./Navbar.4e2044fd.js";import"./OmniChat.23804570.js";import"./gateway.e14a87cc.js";import"./popupNotifcation.55c3d770.js";import"./AbstraLogo.vue_vue_type_script_setup_true_lang.44247f27.js";import"./Logo.00f1cdb8.js";import"./uuid.90494b4a.js";import"./PhClockCounterClockwise.vue.46c3e40e.js";import"./omniChatStore.dbe1dbde.js";import"./record.6981eb70.js";import"./LoadingOutlined.2bc654ae.js";import"./columns.5de4a954.js";import"./string.33cd155c.js";import"./linters.7f594867.js";import"./asyncComputed.883f99d7.js";import"./controller.15e25fab.js";import"./workspaces.0f10707a.js";import"./runnerData.a36e7caa.js";import"./url.058cc2c6.js";import"./colorHelpers.c372ec9c.js";import"./index.2898db4b.js";import"./validations.e0736aad.js";import"./metadata.fd28ad62.js";import"./PhWebhooksLogo.vue.8b359f70.js";import"./controller.1c462665.js";import"./fetch.29ff9ac6.js";import"./PhPencil.vue.f45c727f.js";import"./project.a76802ac.js";import"./requirements.9b99c233.js";import"./object.12aebb19.js";import"./scripts.c09fb5d3.js";import"./PhCopySimple.vue.3f650977.js";import"./index.84fdff7c.js";import"./CollapsePanel.ace339ae.js";import"./Avatar.459ee620.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang.da027e00.js";import"./PhArrowCounterClockwise.vue.1db8cbe2.js";import"./PhFilePy.vue.021d33ce.js";import"./PhChats.vue.1d2c08c1.js";import"./PhRocket.vue.9e3124b6.js";import"./PhPackage.vue.67273894.js";import"./userStore.ae2e441a.js";import"./polling.773eec85.js";import"./PhArrowSquareOut.vue.bea4815d.js";import"./PhDotsThree.vue.b867e178.js";import"./PhSignOut.vue.aecb5a1e.js";import"./PhSparkle.vue.38cf38b5.js";import"./editor.65e93d79.js";import"./workspaceStore.933ebf86.js";import"./index.c0748d2f.js";import"./CloseCircleOutlined.13af90fa.js";import"./CheckCircleFilled.22f5a6e6.js";import"./index.378659cf.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="65c9367f-f2f1-422d-b481-e0eb11faaa50",t._sentryDebugIdIdentifier="sentry-dbid-65c9367f-f2f1-422d-b481-e0eb11faaa50")}catch{}})();const yt=a({__name:"Workspace",setup(t){const o=n();return(p,l)=>{const m=s("RouterView");return c(),f(e,null,{navbar:r(()=>[i(d,{"page-title":u(o).meta.title},null,8,["page-title"])]),content:r(()=>[i(m)]),chat:r(()=>[i(_)]),_:1})}}});export{yt as default};
//# sourceMappingURL=Workspace.634fc41d.js.map
