import{O as r}from"./userStore.ae2e441a.js";import{d as l,J as i,K as c,b as a,w as n,u as o,o as u,az as s,d6 as f,d5 as b}from"./index.a59ca186.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e0cf5ed1-1139-4c96-83b9-9b6375e21fa3",e._sentryDebugIdIdentifier="sentry-dbid-e0cf5ed1-1139-4c96-83b9-9b6375e21fa3")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new r().loginCallback()}),(t,d)=>(u(),c("div",null,[a(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.ff2782cf.js.map
