import{G as c,dv as s,dw as i}from"./index.a59ca186.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c94a3d54-f272-410e-b62c-5bd76e81227d",e._sentryDebugIdIdentifier="sentry-dbid-c94a3d54-f272-410e-b62c-5bd76e81227d")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:d}=s(i),u=c(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:d,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(d.name,d),e.component(r.name,r),e.component(t.name,t),e.component(o.name,o),e)});export{u as D,r as M,o as Q,d as R,t as W};
//# sourceMappingURL=dayjs.2d513ded.js.map
