import{_ as d}from"./TasksView.vue_vue_type_script_setup_true_lang.fb6d29e2.js";import{L as p}from"./tasksController.0c3cb2d7.js";import{d as f,f as u,c as _,w as t,o as m,b as s,u as o,d6 as y,az as i,bM as b,da as k,Q as w}from"./index.a59ca186.js";import{C as g}from"./ContentLayout.3abdf426.js";import{a as T}from"./ant-design.c46171b2.js";import"./metadata.fd28ad62.js";import"./PhWebhooksLogo.vue.8b359f70.js";import"./string.33cd155c.js";import"./index.1cf59b43.js";import"./dayjs.2d513ded.js";import"./gateway.e14a87cc.js";import"./popupNotifcation.55c3d770.js";import"./linters.7f594867.js";import"./asyncComputed.883f99d7.js";import"./scripts.c09fb5d3.js";import"./record.6981eb70.js";import"./polling.773eec85.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="7ae1cb9b-6931-480b-9c89-5dcd3f89242c",e._sentryDebugIdIdentifier="sentry-dbid-7ae1cb9b-6931-480b-9c89-5dcd3f89242c")}catch{}})();const x=f({__name:"Tasks",setup(e){const a=new p,r=u(null);async function l(){var n;await T("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(c,n)=>(m(),_(g,null,{default:t(()=>[s(o(k),{justify:"space-between",align:"center"},{default:t(()=>[s(o(y),null,{default:t(()=>[i("Tasks")]),_:1}),s(o(b),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:t(()=>[i("Clear all")]),_:1})]),_:1}),s(d,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const $=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{$ as default};
//# sourceMappingURL=Tasks.fabf3432.js.map
