import{d as l,eo as i,g as r,o as a,K as t,F as c,ec as g,eb as p,Q as u}from"./index.a59ca186.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="2b37b749-5cca-4906-8f73-c85680d3c781",e._sentryDebugIdIdentifier="sentry-dbid-2b37b749-5cca-4906-8f73-c85680d3c781")}catch{}})();const _={class:"logo"},f=["src","alt"],m=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const s=e;i(o=>({"4521d904":n.value}));const n=r(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),d=r(()=>`${s.brandName} Logo`);return(o,b)=>(a(),t("div",_,[o.imageUrl?(a(),t("img",{key:0,class:"logo-img",src:o.imageUrl,alt:d.value},null,8,f)):c("",!0),o.hideText?c("",!0):(a(),t("span",{key:1,class:g(o.size)},p(o.brandName),3))]))}});const h=u(m,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.00f1cdb8.js.map
