import{d as i,c as p,w as n,o as m,b as a,u as e}from"./index.a59ca186.js";import"./linters.7f594867.js";import{W as d}from"./workspaces.0f10707a.js";import{C as s}from"./ContentLayout.3abdf426.js";import{E as f}from"./controller.1c462665.js";import{_ as u}from"./View.vue_vue_type_script_setup_true_lang.855386dc.js";import"./asyncComputed.883f99d7.js";import"./runnerData.a36e7caa.js";import"./url.058cc2c6.js";import"./colorHelpers.c372ec9c.js";import"./record.6981eb70.js";import"./gateway.e14a87cc.js";import"./popupNotifcation.55c3d770.js";import"./fetch.29ff9ac6.js";import"./PhPencil.vue.f45c727f.js";import"./SaveButton.27a105d7.js";import"./UnsavedChangesHandler.70782e80.js";import"./ExclamationCircleOutlined.a7d6c013.js";import"./CrudView.cdf2b3ec.js";import"./router.179446c8.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.e785979a.js";import"./PhDotsThreeVertical.vue.b78f3770.js";import"./Badge.d0d1aeb3.js";import"./index.c0748d2f.js";import"./index.1cf59b43.js";import"./polling.773eec85.js";import"./omniChatStore.dbe1dbde.js";import"./index.378659cf.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="bd4e4026-7a7e-4e27-af6d-bd15dbe40f79",o._sentryDebugIdIdentifier="sentry-dbid-bd4e4026-7a7e-4e27-af6d-bd15dbe40f79")}catch{}})();const H=i({__name:"EnvVarsEditor",setup(o){const r=new f;return(t,c)=>(m(),p(s,null,{default:n(()=>[a(u,{"env-var-repository":e(r),mode:"editor","file-opener":e(d)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{H as default};
//# sourceMappingURL=EnvVarsEditor.c98cb64e.js.map
